@@ -3,13 +3,17 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "mainjob.h"
+#include "DDLog.h"
 
 #include <QLoggingCategory>
 
+using namespace DDLog;
+
 static MainJob *mainJob = nullptr;
 
 extern "C" int DSMRegister(const char *name, void *data)
 {
+    qCDebug(appLog) << "Enter DSMRegister, name:" << name;
     (void)data;
     mainJob = new MainJob(name);
     return 0;
@@ -17,6 +21,7 @@ extern "C" int DSMRegister(const char *name, void *data)
 
 extern "C" int DSMUnRegister(const char *name, void *data)
 {
+    qCDebug(appLog) << "Enter DSMUnRegister, name:" << name;
     (void)name;
     (void)data;
     mainJob->deleteLater();
