@@ -26,6 +26,7 @@ void SingleDeviceManager::activateWindow()
         m_qspMainWnd.reset(new MainWindow());
         Dtk::Widget::moveToCenter(m_qspMainWnd.get());
         m_qspMainWnd->show();
+        qCDebug(appLog) << "Main window created and shown.";
         QJsonObject obj{
             {"tid", EventLogUtils::Start},
             {"version", QCoreApplication::applicationVersion()},
@@ -36,9 +37,11 @@ void SingleDeviceManager::activateWindow()
         m_qspMainWnd->setWindowState(Qt::WindowActive);
         m_qspMainWnd->activateWindow(); // Reactive main window
         m_qspMainWnd->showNormal();     //非特效模式下激活窗口
+        qCDebug(appLog) << "Main window already exists, activated and shown.";
     }
     if (!m_PageDescription.isEmpty()) {
         QMetaObject::invokeMethod(m_qspMainWnd.get(), "slotSetPage", Qt::QueuedConnection, Q_ARG(QString, m_PageDescription));
+        qCDebug(appLog) << "Setting page to:" << m_PageDescription;
     }
 }
 
@@ -54,13 +57,16 @@ bool SingleDeviceManager::parseCmdLine()
 
     if (!m_PageDescription.isEmpty()) {
         m_PageDescription.clear();
+        qCDebug(appLog) << "Cleared existing page description.";
     }
     QStringList paraList = parser.positionalArguments();
     if (!paraList.isEmpty()) {
         m_PageDescription = paraList[0];
+        qCDebug(appLog) << "Parsed page description:" << m_PageDescription;
     }
 
     if (paraList.size() > 0 && m_PageDescription.isEmpty()) {
+        qCWarning(appLog) << "Positional arguments exist but page description is empty, returning false.";
         return false;
     }
     qCDebug(appLog) << "SingleDeviceManager::parseCmdLine() result:" << true;
@@ -76,6 +82,7 @@ void SingleDeviceManager::startDeviceManager(QString pageDescription)
     } else {
         qCDebug(appLog) << "SingleDeviceManager::startDeviceManager with empty page";
         if (m_qspMainWnd.get()) {                   //先判断当前是否已经存在一个进程。
+            qCDebug(appLog) << "Main window exists, activating it.";
             m_qspMainWnd.get()->setWindowState((m_qspMainWnd.get()->windowState() & ~Qt::WindowMinimized) | Qt::WindowActive);
 //            m_qspMainWnd.get()->activateWindow();   //特效模式下激活窗口            m_qspMainWnd.get()->showNormal();       //无特效激活窗口
         }
