@@ -8,6 +8,7 @@
 
 // 其它头文件
 #include <QString>
+#include <QStringList>
 
 class Common
 {
@@ -36,5 +37,7 @@ public:
      * special computer type:PGUW(value:1),KLVV/L540(value:2),KLVU(value:3),PGUV/W585(value:4)
      */
     static int specialComType;
+
+    static QByteArray executeClientCmd(const QString& cmd, const QStringList& args = QStringList(), const QString& workPath = QString(), int msecsWaiting = 30000, bool useEnv = true);
 };
 #endif // COMMONFUNCTION_H
